@@ -147,6 +147,14 @@ class CompositeSemaphore(object):
             return
 
         with self.right_lock:
+            # this prevents rights from getting
+            # overwritten and hanging forever
+            # handle appropriately at Event level
+            if identifier in self.semaphores:
+                raise Exception(
+                    "right identifier already exists: {}".format(
+                        identifier))
+
             self.semaphores[identifier] = (
                 mutable_shared,
                 threading.Semaphore(1)
